
# Type: population to population association_relation




URI: [biolink:population_to_population_association_relation](https://w3id.org/biolink/vocab/population_to_population_association_relation)


## Domain and Range

[PopulationToPopulationAssociation](PopulationToPopulationAssociation.md) ->  <sub>REQ</sub> [Uriorcurie](types/Uriorcurie.md)

## Parents

 *  is_a: [relation](relation.md)

## Children


## Used by

 * [PopulationToPopulationAssociation](PopulationToPopulationAssociation.md)
